@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for sagemaker-a2i-runtime service client
 
@@ -10,11 +11,12 @@ Usage::
     client: AugmentedAIRuntimeClient = boto3.client("sagemaker-a2i-runtime")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from datetime import datetime
 import sys
-from typing import Any, Dict, TYPE_CHECKING, Type, overload
+from datetime import datetime
+from typing import Any, Dict, Type
+
 from botocore.exceptions import ClientError as Boto3ClientError
+
 from mypy_boto3_sagemaker_a2i_runtime.paginator import ListHumanLoopsPaginator
 from mypy_boto3_sagemaker_a2i_runtime.type_defs import (
     DescribeHumanLoopResponseTypeDef,
@@ -105,7 +107,6 @@ class AugmentedAIRuntimeClient:
         [Client.stop_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.stop_human_loop)
         """
 
-    @overload
     def get_paginator(self, operation_name: Literal["list_human_loops"]) -> ListHumanLoopsPaginator:
         """
         [Paginator.ListHumanLoops documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)
