@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for sagemaker-a2i-runtime service client paginators.
 
@@ -16,11 +17,12 @@ Usage::
     list_human_loops_paginator: ListHumanLoopsPaginator = client.get_paginator("list_human_loops")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from datetime import datetime
 import sys
-from typing import Iterator, TYPE_CHECKING
+from datetime import datetime
+from typing import Iterator
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_sagemaker_a2i_runtime.type_defs import (
     ListHumanLoopsResponseTypeDef,
     PaginatorConfigTypeDef,
